[Libreoffice-commits] core.git: vcl/workben

Caolán McNamara caolanm at redhat.com
Thu Aug 1 14:12:52 PDT 2013


 vcl/workben/outdevgrind.cxx |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 27b83b89f13ac4ad0577ee27f13d9c6843ee66d4
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Aug 1 16:08:30 2013 +0100

    update signature of DrawTextArray in workben
    
    left behind since 0c7579d5de63f569773daf894bcc0ab173223f2a
    
    Change-Id: Ide1f81e5af52bece9ef96cfb1c16948086908e22

diff --git a/vcl/workben/outdevgrind.cxx b/vcl/workben/outdevgrind.cxx
index 261643d..79137b8 100644
--- a/vcl/workben/outdevgrind.cxx
+++ b/vcl/workben/outdevgrind.cxx
@@ -109,7 +109,7 @@ void setupMethodStubs( functor_vector_type& res )
     aPoly3.Rotate( aPoly3.GetBoundRect().Center(),
                    900 );
 
-    const String      aString("This is a test");
+    const OUString    aString("This is a test");
     const LineInfo    aLineInfo(LINE_SOLID,5);
 
     // unfortunately, VDevs have inaccessible copy constructors
@@ -139,7 +139,7 @@ void setupMethodStubs( functor_vector_type& res )
     aMtf.AddAction( new MetaFillColorAction(Color(COL_RED),sal_True) );
     aMtf.AddAction( new MetaRectAction(aRect) );
 
     /* void DrawTextArray( const Point& rStartPt, const XubString& rStr,
                                        const sal_Int32* pDXAry = NULL,
                                        xub_StrLen nIndex = 0,
                                        xub_StrLen nLen = STRING_LEN );
@@ -149,7 +149,7 @@ void setupMethodStubs( functor_vector_type& res )
         boost::bind(
             &OutputDevice::DrawTextArray,
             _1,
-            aPt1, aString, (const sal_Int32*)0, (sal_uInt16)0, aString.Len() ));
+            aPt1, aString, (const sal_Int32*)0, (sal_uInt16)0, aString.getLength() ));
 
     /* void DrawPixel( const Point& rPt, const Color& rColor ); */
     add(res,
@@ -139,7 +139,7 @@ void setupMethodStubs( functor_vector_type& res )
     aMtf.AddAction( new MetaRectAction(aRect) );
 
-    /* void DrawTextArray( const Point& rStartPt, const XubString& rStr,
+    /* void DrawTextArray( const Point& rStartPt, const OUString& rStr,
                                        const sal_Int32* pDXAry = NULL,
                                        xub_StrLen nIndex = 0,


More information about the Libreoffice-commits mailing list